# pybenproxmox
PyBEN Proxmox repository is an easy to use python utility class for Proxmox server solution

## proxmox_utils

### Proxmox class
Some of the included functions:
 - get_vms: Returns a full list of vms, or list with matching vms by id or name
 - clone_vms
 - migrate_vm_to_node
 - delete_vm
 - start_vm
 - stop_vm
 - snapshot handling
 - and more ...